﻿;/////////////////////////////////////////////////////////////////////////////////
;Demo of the OOP class for implementing memory files.

;Demonstrates some of the methods exposed by the 'MemoryFileObject' class.
;/////////////////////////////////////////////////////////////////////////////////

XIncludeFile "memoryFileClass.pbi"


;Create a MemoryFile object with initial size 100 bytes and page size 50 bytes.

   MyMemoryFileObject.MemoryFileObject
   MyMemoryFileObject = NewMemoryFile(100, 50)

If MyMemoryFileObject ;Always check that the object was created successfully.

  ;Let us write some doubles to the buffer.
    For i = 0 To 9
      MyMemoryFileObject\WriteDouble(i+0.5)
    Next

  ;Take a look how much data has been written (assuming that none of the write operations returned any errors - which we should have checked!)
    count = MyMemoryFileObject\Lof()
    Debug "Written " + Str(count) + " bytes in total."
    Debug "==================="

  ;Let us take a look at the data.
    MyMemoryFileObject\FileSeek(0)
    Debug "Doubles written ....."
      While MyMemoryFileObject\Eof() = 0
        Debug "   " + StrD(MyMemoryFileObject\ReadDouble())
      Wend
    Debug "==================="
    Debug ""
    
  ;Let us append some 'longs'. The file pointer is already at the end of the file.
    currentPos = MyMemoryFileObject\Loc()  ;So that we can return to this point later.
    For i = 0 To 9
      MyMemoryFileObject\WriteLong(i*1000)
    Next 
    
  ;Take a look how much data has been written (assuming that none of the write operations returned any errors - which we should have checked!)
    count = MyMemoryFileObject\Lof()
    Debug "Written " + Str(count) + " bytes in total."
    Debug "==================="

  ;Let us take a look at the data.
    MyMemoryFileObject\FileSeek(currentPos)
    Debug "Longs appended ....."
      While MyMemoryFileObject\Eof() = 0
        Debug "   " + Str(MyMemoryFileObject\ReadLong())
      Wend
    Debug "==================="
    Debug ""

  ;Let us add a couple of strings in utf-8 format! (These include null terminators!)
    currentPos = MyMemoryFileObject\Loc()  ;So that we can return to this point later.
    MyMemoryFileObject\WriteString("Hello my old mucka!", #PB_UTF8)
    MyMemoryFileObject\WriteString("Sausages!",#PB_UTF8)

  ;Take a look how much data has been written (assuming that none of the write operations returned any errors - which we should have checked!)
    count = MyMemoryFileObject\Lof()
    Debug "Written " + Str(count) + " bytes in total."
    Debug "==================="

  ;Let us take a look at the data.
    MyMemoryFileObject\FileSeek(currentPos)
    Debug "Strings appended ....."
      While MyMemoryFileObject\Eof() = 0
        Debug "   " + MyMemoryFileObject\ReadString(#PB_UTF8)
      Wend
    Debug "==================="

  ;Destroy the array once it is no longer required.
  ;By not setting the optional parameter to #False, we are opting to free the memory buffer itself (on top of deleting the object).
    MyMemoryFileObject\Destroy()
Else
  MessageRequester("Error :", "There was a memory allocation problem creating the memory buffer object.")
EndIf



; IDE Options = PureBasic 4.61 (Windows - x86)
; CursorPosition = 17
; FirstLine = 17
; EnableAsm
; EnableUnicode