﻿;/////////////////////////////////////////////////////////////////////////////////
;An OOP class for implementing dynamic memory files.

;nxSoftware.com
;January 2010.

;Header file.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-Class interfaces.

  ;The following interface contains the base class methods.
    Interface MemoryFileObject
      CheckForErrors.i()                    ;Returns #True if an error has been recorded against any 'write' operation (since the last
                                            ;call to ClearErrorFlag()).
                                            ;Used when checking for errors after a 'bulk' set of write operations etc. as opposed to
                                            ;checking each individual 'write'. A failed 'write' will not cause a crash.
      ClearErrorFlag()
      Destroy.i(blnFreeFileMemory=#True)    ;Set blnFreeFileMemory to #False if the underlying memory is not to be freed.
                                            ;In this case, the return value is a pointer to the underlying memory which can be freed later
                                            ;with FreeMemory() etc. Use the Lof() method first if required.
      Eof.i()                               ;Returns #True if the file pointer is at or past the end of the file.
      FileSeek.i(newOffset.i)               ;Relative to the beginning of the file.
                                            ;The file will be extended and null-padded if the file-pointer is moved bey0nd the end of the file etc.
                                            ;Returns zero if error.
      GetFileMemoryBase.i()                 ;THIS ADDRESS CAN CHANGE AFTER USING ANY OF THE 'Write...()' METHODS!!!
      Loc.i()                               ;Returns the current file position as an offset from the beginning of the file.
      Lof.i()
      ;Read methods----------------------------------------------------------------------------------------------------------------------
      ;These all read from the current file position.
        ReadByte.b()
        ReadCharacter.c()
        ReadData.i(memoryBuffer, lengthToRead)  ;Returns the number of bytes actually read.
        ReadDouble.d()
        ReadFloat.f()
        ReadInteger.i()
        ReadLong.l()
        ReadQuad.q()
        ReadString.s(format=0)              ;Omit format to read the string in unicode if the program is compiled in unicode mode or ascii...
                                            ;Otherwise format can take one of the values #PB_Unicode, #PB_UTF8 or #PB_Ascii.
                                            ;Reading finishes when the appropriate null-terminator is encountered (or the end of the file).
        ReadWord.w()
      ;-----------------------------------------------------------------------------------------------------------------------------------
      Reset.i(newInitialSize=-1)            ;Clears the data, resets the file size to the new size, zeros the file pointer,
                                            ;clears the error flag etc.
                                            ;Returns zero if error. In which case the existing memory file is left unchanged.
      ;Write methods---------------------------------------------------------------------------------------------------------------------
      ;These all write starting at the current file position.
        WriteByte.i(byte.b)                 ;Returns zero if error. The only possible error is if extra memory is required and the subsequent memory re-allocation fails.
        WriteCharacter.i(char.c)            ;Returns zero if error. The only possible error is if extra memory is required and the subsequent memory re-allocation fails.
        WriteData.i(memoryBuffer, length)   ;Returns zero if error.
        WriteDouble.i(double.d)             ;Returns zero if error. The only possible error is if extra memory is required and the subsequent memory re-allocation fails.
        WriteFloat.i(long.f)                ;Returns zero if error. The only possible error is if extra memory is required and the subsequent memory re-allocation fails.
        WriteInteger.i(integer.i)           ;Returns zero if error. The only possible error is if extra memory is required and the subsequent memory re-allocation fails.
        WriteLong.i(long.l)                 ;Returns zero if error. The only possible error is if extra memory is required and the subsequent memory re-allocation fails.
        WriteQuad.i(quad.q)                 ;Returns zero if error. The only possible error is if extra memory is required and the subsequent memory re-allocation fails.
        WriteString.i(text$, format=0)      ;Omit format to write the string in unicode if the program is compiled in unicode mode or ascii...
                                            ;Otherwise format can take one of the values #PB_Unicode, #PB_UTF8 or #PB_Ascii.
                                            ;The appropriate null-terminator is written.
        WriteWord.i(word.w)                 ;Returns zero if error. The only possible error is if extra memory is required and the subsequent memory re-allocation fails.
      ;-----------------------------------------------------------------------------------------------------------------------------------
    EndInterface

; IDE Options = PureBasic 4.61 Beta 1 (Windows - x86)
; CursorPosition = 34
; FirstLine = 29